@@ -565,9 +565,9 @@ def dropkick(
         a.obs.drop(columns=["dropkick_label"], inplace=True)
     adata.obs.loc[a.obs_names, "dropkick_label"] = rc_.predict(X)
     adata.obs.dropkick_label.fillna(0, inplace=True)  # fill ignored cells with zeros
-    adata.obs.dropkick_label = adata.obs.dropkick_label.astype(bool).astype(
-        "category"
-    )  # convert to categorical dtype
+    adata.obs.dropkick_label = (
+        adata.obs.dropkick_label.astype(bool).astype(str).astype("category")
+    )  # convert to categorical strings
     for metric in metrics:
         adata.obs.loc[a.obs_names, metric] = a.obs[metric]
         adata.obs[metric].fillna(0, inplace=True)  # fill ignored cells with zeros
